diff --git a/core/lib/Drupal/Core/Entity/EntityReferenceSelection/SelectionPluginManager.php b/core/lib/Drupal/Core/Entity/EntityReferenceSelection/SelectionPluginManager.php
index af1c269..2c3fa6d 100644
--- a/core/lib/Drupal/Core/Entity/EntityReferenceSelection/SelectionPluginManager.php
+++ b/core/lib/Drupal/Core/Entity/EntityReferenceSelection/SelectionPluginManager.php
@@ -47,29 +47,20 @@ public function getInstance(array $options) {
       'handler_settings' => array(),
     );
 
-    // A specific selection plugin ID was already specified.
-    if (strpos($options['handler'], ':') !== FALSE) {
-      $plugin_id = $options['handler'];
-    }
-    // Only a selection group name was specified.
-    else {
-      $plugin_id = $this->getPluginId($options['target_type'], $options['handler']);
-    }
-
-    return $this->createInstance($plugin_id, $options);
+    return $this->createInstance($options['handler'], $options);
   }
 
   /**
    * {@inheritdoc}
    */
-  public function getPluginId($target_type, $base_plugin_id) {
+  public function getPluginId($target_type, $selection_group) {
     // Get all available selection plugins for this entity type.
     $selection_handler_groups = $this->getSelectionGroups($target_type);
 
     // Sort the selection plugins by weight and select the best match.
-    uasort($selection_handler_groups[$base_plugin_id], array('Drupal\Component\Utility\SortArray', 'sortByWeightElement'));
-    end($selection_handler_groups[$base_plugin_id]);
-    $plugin_id = key($selection_handler_groups[$base_plugin_id]);
+    uasort($selection_handler_groups[$selection_group], array('Drupal\Component\Utility\SortArray', 'sortByWeightElement'));
+    end($selection_handler_groups[$selection_group]);
+    $plugin_id = key($selection_handler_groups[$selection_group]);
 
     return $plugin_id;
   }
diff --git a/core/lib/Drupal/Core/Entity/EntityReferenceSelection/SelectionPluginManagerInterface.php b/core/lib/Drupal/Core/Entity/EntityReferenceSelection/SelectionPluginManagerInterface.php
index a318611..ed02c84 100644
--- a/core/lib/Drupal/Core/Entity/EntityReferenceSelection/SelectionPluginManagerInterface.php
+++ b/core/lib/Drupal/Core/Entity/EntityReferenceSelection/SelectionPluginManagerInterface.php
@@ -21,13 +21,13 @@
    *
    * @param string $target_type
    *   The target entity type.
    * @param string $base_plugin_id
    *   The base plugin ID (e.g. 'default' or 'views').
    *
    * @return string
    *   The plugin ID.
    */
-  public function getPluginId($target_type, $base_plugin_id);
+  public function getPluginId($target_type, $selection_group);
 
   /**
    * Gets the selection plugins that can reference a specific entity type.
@@ -21,13 +21,13 @@
    * @param string $target_type
    *   The target entity type.
-   * @param string $base_plugin_id
-   *   The base plugin ID (e.g. 'default' or 'views').
+   * @param string $selection_group
+   *   The ID of the selection group (e.g. 'default' or 'views').
    *
    * @return string
